/**
 * Copyright (c) 2006-2011 Berlin Brown.  All Rights Reserved
 *
 * http://www.opensource.org/licenses/bsd-license.php
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 * * Neither the name of the Botnode.com (Berlin Brown) nor
 * the names of its contributors may be used to endorse or promote
 * products derived from this software without specific prior written permission.
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * Date: 8/15/2011
 *  
 * Description: LogFile Searcher.  Search log file and build statistics from the scan.
 * 
 * Contact: Berlin Brown <berlin dot brown at gmail.com>
 */
package org.berlin.logs.scan.session.custom.app;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.Properties;

import org.berlin.logs.scan.GlobalConfiguration;
import org.berlin.logs.scan.Version;

/**
 * Main entry for parser application.
 */
public class Main {
 
  /**
   * Main entry point for parser application.
   * 
   * @param args
   * @throws Exception
   */
  public static void main(final String [] args) throws Exception {
    
    /****************************************
     * Load from the classpath, then the filesystem and then from the command console.
     ****************************************/
    final File fConfLocal = new File("log_scan_system.properties");
    final Properties propsLocalFile = new Properties();
    if (fConfLocal.exists()) {
        System.out.println("Conf Exists, attempting to load - " + fConfLocal.getAbsolutePath());            
        try {
            propsLocalFile.load(new FileInputStream(fConfLocal));
        } catch (FileNotFoundException e) {
            e.printStackTrace();
        } catch (IOException e) {
            e.printStackTrace();
        }
    } // End of the if //
    final GlobalConfiguration globalConf = new GlobalConfiguration().load(GlobalConfiguration.PATH);
    globalConf.loadFromDynamicScript(propsLocalFile);        
    System.out.println(globalConf);        
    System.out.println(Version.num + " -- " + globalConf.getSystemApplicationName() + "-" + globalConf.getSystemVersion());
       
    final ExpressionRunner express = new ExpressionRunner();
    express.globalConf = globalConf;
    express.run();
  }
 
} // End of the Class //
